pub struct FulfillmentDocument {
    pub upload_destination_id: Option<String>,
    pub content_sha256: Option<String>,
}
FulfillmentDocument : Document that captured during service appointment fulfillment that portrays proof of completion

Fields

upload_destination_id: Option<String>

The identifier of the upload destination. Get this value by calling the createServiceDocumentUploadDestination operation of the Services API.

content_sha256: Option<String>

Sha256 hash of the file content. This value is used to determine if the file has been corrupted or tampered with during transit.

Implementations

Document that captured during service appointment fulfillment that portrays proof of completion